@@ -825,13 +825,19 @@ class TableAdapter(WsdlAdapter):
     fields = WsdlAdapter.StringArray("fields")
     head = WsdlAdapter.StringArray("head")
 
+    @classmethod
+    def get_matrix(self, value):
+        if hasattr(value, 'stringArray'):
+            return [row.string
+                    for row in value.stringArray
+                    if hasattr(row, "string")]
+        elif isinstance(value, list):
+            return value
+        return []
+
     @property
     def body(self):
-        if hasattr(self.source.body, 'stringArray'):
-            return [row.string
-                    for row in self.source.body.stringArray
-                    if hasattr(row, "string")]
-        return []
+        return self.get_matrix(self.source.body)
 
     values = WsdlAdapter.Array("values", ChoiceValueAdapter)
 
